Selection
=========

.. toctree::
  :maxdepth: 1

  Selector <_autosummary/stk.Selector>
  Above Average <_autosummary/stk.AboveAverage>
  Best <_autosummary/stk.Best>
  Filter Batches <_autosummary/stk.FilterBatches>
  Filter Molecules <_autosummary/stk.FilterMolecules>
  Remove Batches <_autosummary/stk.RemoveBatches>
  Remove Molecules <_autosummary/stk.RemoveMolecules>
  Roulette <_autosummary/stk.Roulette>
  Stochastic Universal Sampling <_autosummary/stk.StochasticUniversalSampling>
  Tournament <_autosummary/stk.Tournament>
  Worst <_autosummary/stk.Worst>
